pub struct HealthTime {
pub remote_time: i64,
pub local_time: i64,
pub diff: i64,
}Expand description
Health Time
Fields
remote_time: i64Current unix timestamp on trustful remote server.
local_time: i64Current unix timestamp of local server where Appwrite runs.
diff: i64Difference of unix remote and local timestamps in milliseconds.
Implementations
Sourceimpl HealthTime
impl HealthTime
Sourcepub fn remote_time(&self) -> &i64
pub fn remote_time(&self) -> &i64
Get remote_time
Sourcepub fn local_time(&self) -> &i64
pub fn local_time(&self) -> &i64
Get local_time