pub struct Table {
pub id: String,
pub created_at: String,
pub updated_at: String,
pub permissions: Vec<String>,
pub database_id: String,
pub name: String,
pub enabled: bool,
pub row_security: bool,
pub columns: Vec<Value>,
pub indexes: Vec<ColumnIndex>,
pub bytes_max: i64,
pub bytes_used: i64,
}Expand description
Table
Fields
id: StringTable ID.
created_at: StringTable creation date in ISO 8601 format.
updated_at: StringTable update date in ISO 8601 format.
permissions: Vec<String>Table permissions. Learn more about permissions.
database_id: StringDatabase ID.
name: StringTable name.
enabled: boolTable enabled. Can be ‘enabled’ or ‘disabled’. When disabled, the table is inaccessible to users, but remains accessible to Server SDKs using API keys.
row_security: boolWhether row-level permissions are enabled. Learn more about permissions.
columns: Vec<Value>Table columns.
indexes: Vec<ColumnIndex>Table indexes.
bytes_max: i64Maximum row size in bytes. Returns 0 when no limit applies.
bytes_used: i64Currently used row size in bytes based on defined columns.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn created_at(&self) -> &String
pub fn created_at(&self) -> &String
Get created_at
Sourcepub fn updated_at(&self) -> &String
pub fn updated_at(&self) -> &String
Get updated_at
Sourcepub fn permissions(&self) -> &Vec<String>
pub fn permissions(&self) -> &Vec<String>
Get permissions
Sourcepub fn database_id(&self) -> &String
pub fn database_id(&self) -> &String
Get database_id
Sourcepub fn row_security(&self) -> &bool
pub fn row_security(&self) -> &bool
Get row_security
Sourcepub fn indexes(&self) -> &Vec<ColumnIndex>
pub fn indexes(&self) -> &Vec<ColumnIndex>
Get indexes
Sourcepub fn bytes_used(&self) -> &i64
pub fn bytes_used(&self) -> &i64
Get bytes_used