pub struct Topic {
pub id: String,
pub created_at: String,
pub updated_at: String,
pub name: String,
pub email_total: i64,
pub sms_total: i64,
pub push_total: i64,
pub subscribe: Vec<String>,
}Expand description
Topic
Fields
id: StringTopic ID.
created_at: StringTopic creation time in ISO 8601 format.
updated_at: StringTopic update date in ISO 8601 format.
name: StringThe name of the topic.
email_total: i64Total count of email subscribers subscribed to the topic.
sms_total: i64Total count of SMS subscribers subscribed to the topic.
push_total: i64Total count of push subscribers subscribed to the topic.
subscribe: Vec<String>Subscribe permissions.
Implementations
Sourceimpl Topic
impl Topic
Sourcepub fn created_at(&self) -> &String
pub fn created_at(&self) -> &String
Get created_at
Sourcepub fn updated_at(&self) -> &String
pub fn updated_at(&self) -> &String
Get updated_at
Sourcepub fn email_total(&self) -> &i64
pub fn email_total(&self) -> &i64
Get email_total
Sourcepub fn push_total(&self) -> &i64
pub fn push_total(&self) -> &i64
Get push_total